@@ -13,6 +13,8 @@ OC.L10N.register(
     "More activities" : "더 많은 활동",
     "Daily activity summary for %s" : "%s 의 일일 활동 요약",
     "_and %n more…_::_and %n more…_" : ["그 외 %n개 더 있음"],
+    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "<a href=\"%s\">설정에서</a> 일일 요약 이메일을 사용하지 않도록 설정할 수 있습니다.",
+    "You can disable daily digest emails in the settings: %s" : "설정에서 일일 요약 이메일을 사용하지 않도록 설정할 수 있습니다: %s",
     "All activities" : "모든 활동",
     "By others" : "다른 사람",
     "By you" : "나",
