@@ -2,37 +2,21 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Frank Karlitschek <frank@karlitschek.de>
- * @author Joas Schilling <coding@schilljs.com>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
-
 namespace OCA\Activity;
 
 use Doctrine\DBAL\Platforms\MySQLPlatform;
 use OCA\Activity\Filter\AllFilter;
+use OCP\Activity\Exceptions\FilterNotFoundException;
 use OCP\Activity\IEvent;
 use OCP\Activity\IExtension;
 use OCP\Activity\IFilter;
 use OCP\Activity\IManager;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\IConfig;
 use OCP\IDBConnection;
 use Psr\Log\LoggerInterface;
 
@@ -48,7 +32,9 @@ class Data {
 	public function __construct(
 		protected IManager $activityManager,
 		protected IDBConnection $connection,
-		protected LoggerInterface $logger) {
+		protected LoggerInterface $logger,
+		protected IConfig $config,
+	) {
 	}
 
 	/**
@@ -181,7 +167,7 @@ class Data {
 		$activeFilter = null;
 		try {
 			$activeFilter = $this->activityManager->getFilterById($filter);
-		} catch (\InvalidArgumentException $e) {
+		} catch (FilterNotFoundException) {
 			// Unknown filter => ignore and show all activities
 		}
 
@@ -223,7 +209,7 @@ class Data {
 				$favoriteFilter = $this->activityManager->getFilterById('files_favorites');
 				/** @var \OCA\Files\Activity\Filter\Favorites $favoriteFilter */
 				$favoriteFilter->filterFavorites($query);
-			} catch (\InvalidArgumentException $e) {
+			} catch (FilterNotFoundException) {
 			}
 		}
 
@@ -334,7 +320,7 @@ class Data {
 				try {
 					$this->activityManager->getFilterById($filterValue);
 					return $filterValue;
-				} catch (\InvalidArgumentException $e) {
+				} catch (FilterNotFoundException) {
 					return 'all';
 				}
 		}
@@ -347,23 +333,33 @@ class Data {
 	 */
 	public function expire($expireDays = 365) {
 		$ttl = (60 * 60 * 24 * max(1, $expireDays));
-
 		$timelimit = time() - $ttl;
-		$this->deleteActivities([
+		$conditions = [
 			'timestamp' => [$timelimit, '<'],
-		]);
+		];
+
+		$excludedUsers = $this->config->getSystemValue('activity_expire_exclude_users', []);
+		if (!empty($excludedUsers)) {
+			foreach ($excludedUsers as $user) {
+				$conditions[] = [
+					'affecteduser' => [$user, '!=']
+				];
+			}
+		}
+
+		$this->deleteActivities($conditions);
 	}
 
 	/**
 	 * Delete activities that match certain conditions
 	 *
 	 * @param array $conditions Array with conditions that have to be met
-	 *                      'field' => 'value'  => `field` = 'value'
-	 *    'field' => array('value', 'operator') => `field` operator 'value'
+	 *                          'field' => 'value'  => `field` = 'value'
+	 *                          'field' => array('value', 'operator') => `field` operator 'value'
 	 */
 	public function deleteActivities($conditions): void {
 		$platform = $this->connection->getDatabasePlatform();
-		if($platform instanceof MySQLPlatform) {
+		if ($platform instanceof MySQLPlatform) {
 			$this->logger->debug('Choosing chunked activity delete for MySQL/MariaDB', ['app' => 'activity']);
 			$this->deleteActivitiesForMySQL($conditions);
 			return;
@@ -482,7 +478,7 @@ class Data {
 		$query->setMaxResults(50000);
 		$result = $query->executeQuery();
 		$count = $result->rowCount();
-		if($count === 0) {
+		if ($count === 0) {
 			return;
 		}
 		$ids = array_map(static function (array $id) {
@@ -494,11 +490,11 @@ class Data {
 		$deleteQuery = $this->connection->getQueryBuilder();
 		$deleteQuery->delete('activity');
 		$deleteQuery->where($deleteQuery->expr()->in('activity_id', $deleteQuery->createParameter('ids'), IQueryBuilder::PARAM_INT_ARRAY));
-		foreach(array_chunk($ids, 1000) as $chunk) {
+		foreach (array_chunk($ids, 1000) as $chunk) {
 			$deleteQuery->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
 			$queryResult += $deleteQuery->executeStatement();
 		}
-		if($queryResult === 50000) {
+		if ($queryResult === 50000) {
 			$this->deleteActivitiesForMySQL($conditions);
 		}
 	}
