@@ -124,8 +124,8 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
     "File not found" : "File not found",
     "_{count} selected_::_{count} selected_" : ["{count} selected","{count} selected"],
-    "Search everywhere …" : "Search everywhere …",
-    "Search here …" : "Search here …",
+    "Search everywhere …" : "Search everywhere …",
+    "Search here …" : "Search here …",
     "Search scope options" : "Search scope options",
     "Search here" : "Search here",
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
@@ -144,7 +144,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Failed to refresh filename sanitization status.",
     "Filename sanitization in progress." : "Filename sanitization in progress.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Currently {processedUsers} of {totalUsers} accounts are already processed.",
-    "Preparing …" : "Preparing …",
+    "Preparing …" : "Preparing …",
     "Refresh" : "Refresh",
     "All files have been santized for Windows filename support." : "All files have been santized for Windows filename support.",
     "Some files could not be sanitized, please check your logs." : "Some files could not be sanitized, please check your logs.",
@@ -159,7 +159,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Sanitize filenames",
     "(starting)" : "(starting)",
     "Fill template fields" : "Fill template fields",
-    "Submitting fields …" : "Submitting fields …",
+    "Submitting fields …" : "Submitting fields …",
     "Submit" : "Submit",
     "Choose a file or folder to transfer" : "Choose a file or folder to transfer",
     "Transfer" : "Transfer",
@@ -183,33 +183,9 @@ OC.L10N.register(
     "Do not show this dialog again." : "Do not show this dialogue again.",
     "Select file or folder to link to" : "Select file or folder to link to",
     "Choose {file}" : "Choose {file}",
-    "Share" : "Share",
-    "Shared by link" : "Shared by link",
-    "Shared" : "Shared",
-    "Switch to list view" : "Switch to list view",
-    "Switch to grid view" : "Switch to grid view",
-    "The file could not be found" : "The file could not be found",
-    "Upload was cancelled by user" : "Upload was cancelled by user",
-    "Not enough free space" : "Not enough free space",
-    "Operation is blocked by access control" : "Operation is blocked by access control",
-    "Error during upload: {message}" : "Error during upload: {message}",
-    "Error during upload, status code {status}" : "Error during upload, status code {status}",
-    "Unknown error during upload" : "Unknown error during upload",
-    "Loading current folder" : "Loading current folder",
-    "Retry" : "Retry",
-    "No files in here" : "No files in here",
-    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
-    "Go back" : "Go back",
-    "Views" : "Views",
-    "Files settings" : "Files settings",
-    "Your files" : "Your files",
-    "Open in files" : "Open in files",
-    "File cannot be accessed" : "File cannot be accessed",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
-    "No search results for “{query}”" : "No search results for “{query}”",
-    "Search for files" : "Search for files",
     "Clipboard is not available" : "Clipboard is not available",
     "WebDAV URL copied" : "WebDAV URL copied",
+    "Files settings" : "Files settings",
     "General" : "General",
     "Default view" : "Default view",
     "All files" : "All files",
@@ -252,12 +228,24 @@ OC.L10N.register(
     "Toggle grid view" : "Toggle grid view",
     "Open file sidebar" : "Open file sidebar",
     "Show those shortcuts" : "Show those shortcuts",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
-    "Failed to toggle Windows filename support" : "Failed to toggle Windows filename support",
-    "Files compatibility" : "Files compatibility",
-    "Enforce Windows compatibility" : "Enforce Windows compatibility",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
+    "Share" : "Share",
+    "Shared by link" : "Shared by link",
+    "Shared" : "Shared",
+    "Switch to list view" : "Switch to list view",
+    "Switch to grid view" : "Switch to grid view",
+    "The file could not be found" : "The file could not be found",
+    "Upload was cancelled by user" : "Upload was cancelled by user",
+    "Not enough free space" : "Not enough free space",
+    "Operation is blocked by access control" : "Operation is blocked by access control",
+    "Error during upload: {message}" : "Error during upload: {message}",
+    "Error during upload, status code {status}" : "Error during upload, status code {status}",
+    "Unknown error during upload" : "Unknown error during upload",
+    "Loading current folder" : "Loading current folder",
+    "Retry" : "Retry",
+    "No files in here" : "No files in here",
+    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
+    "Go back" : "Go back",
+    "Views" : "Views",
     "You" : "You",
     "Shared multiple times with different people" : "Shared multiple times with different people",
     "Unable to change the favorite state of the file" : "Unable to change the favorite state of the file",
@@ -266,14 +254,26 @@ OC.L10N.register(
     "Remove from favorites" : "Remove from favourites",
     "Add to favorites" : "Add to favourites",
     "Tags" : "Tags",
+    "Your files" : "Your files",
+    "Open in files" : "Open in files",
+    "File cannot be accessed" : "File cannot be accessed",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
+    "No search results for “{query}”" : "No search results for “{query}”",
+    "Search for files" : "Search for files",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
+    "Failed to toggle Windows filename support" : "Failed to toggle Windows filename support",
+    "Files compatibility" : "Files compatibility",
+    "Enforce Windows compatibility" : "Enforce Windows compatibility",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
     "Blank" : "Blank",
     "Unable to create new file from template" : "Unable to create new file from template",
     "Pick a template for {name}" : "Pick a template for {name}",
     "Create a new file with the selected template" : "Create a new file with the selected template",
     "Creating file" : "Creating file",
     "Save as {displayName}" : "Save as {displayName}",
-    "Save as …" : "Save as …",
-    "Converting files …" : "Converting files …",
+    "Save as …" : "Save as …",
+    "Converting files …" : "Converting files …",
     "Failed to convert files: {message}" : "Failed to convert files: {message}",
     "All files failed to be converted" : "All files failed to be converted",
     "One file could not be converted: {message}" : "One file could not be converted: {message}",
@@ -281,7 +281,7 @@ OC.L10N.register(
     "_One file successfully converted_::_%n files successfully converted_" : ["One file successfully converted","%n files successfully converted"],
     "Files successfully converted" : "Files successfully converted",
     "Failed to convert files" : "Failed to convert files",
-    "Converting file …" : "Converting file …",
+    "Converting file …" : "Converting file …",
     "File successfully converted" : "File successfully converted",
     "Failed to convert file: {message}" : "Failed to convert file: {message}",
     "Failed to convert file" : "Failed to convert file",
@@ -302,8 +302,8 @@ OC.L10N.register(
     "Download" : "Download",
     "The requested file is not available." : "The requested file is not available.",
     "The requested files are not available." : "The requested files are not available.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
     "Destination is not a folder" : "Destination is not a folder",
     "This file/folder is already in that directory" : "This file/folder is already in that directory",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
@@ -394,117 +394,23 @@ OC.L10N.register(
     "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
-    "File could not be found" : "File could not be found",
-    "Show list view" : "Show list view",
-    "Show grid view" : "Show grid view",
-    "Close" : "Close",
-    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
-    "This will stop your current uploads." : "This will stop your current uploads.",
-    "Upload cancelled." : "Upload cancelled.",
-    "Processing files …" : "Processing files …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
-    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
-    "An unknown error has occurred" : "An unknown error has occurred",
-    "File could not be uploaded" : "File could not be uploaded",
-    "Uploading …" : "Uploading …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Uploading … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Uploading that item is not supported",
-    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
-    "Choose target folder" : "Choose target folder",
-    "Set reminder" : "Set reminder",
-    "Edit locally" : "Edit locally",
-    "Open" : "Open",
-    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
-    "Apply tag(s) to selection" : "Apply tag(s) to selection",
-    "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
-    "Unable to determine date" : "Unable to determine date",
-    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
-    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
-    "Could not move \"{file}\"" : "Could not move \"{file}\"",
-    "copy" : "copy",
-    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
-    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
-    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
-    "{newName} already exists" : "{newName} already exists",
-    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
-    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
-    "Could not fetch file details \"{file}\"" : "Could not fetch file details \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Enter more than two characters to search in other folders",
-    "{dirs} and {files}" : "{dirs} and {files}",
-    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
-    "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
-    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
-    "New" : "New",
-    "New file/folder menu" : "New file/folder menu",
-    "Select file range" : "Select file range",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} used",
-    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
-    "File name cannot be empty." : "File name cannot be empty.",
-    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Storage of {owner} is full, files cannot be updated or synced anymore!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Your storage is full, files cannot be updated or synced anymore!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Storage of {owner} is almost full ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Your storage is almost full ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direct link was copied (only works for people who have access to this file/folder)",
-    "Path" : "Path",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favored" : "Favoured",
-    "Favor" : "Favour",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copy direct link (only works for people who have access to this file/folder)",
-    "Upload file" : "Upload file",
-    "Not favored" : "Not favoured",
-    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
+    "%1$s (renamed)" : "%1$s (renamed)",
+    "renamed file" : "renamed file",
     "Upload (max. %s)" : "Upload (max. %s)",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
-    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
-    "Submitting fields…" : "Submitting fields…",
-    "Filter filenames…" : "Filter filenames…",
+    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
+    "Submitting fields …" : "Submitting fields …",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
+    "Filter file names …" : "Filter file names …",
     "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
     "Enable the grid view" : "Enable the grid view",
     "Enable folder tree" : "Enable folder tree",
     "Copy to clipboard" : "Copy to clipboard",
     "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
-    "Deletion cancelled" : "Deletion cancelled",
-    "Move cancelled" : "Move cancelled",
-    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
-    "Cancelled move or copy operation" : "Cancelled move or copy operation",
-    "Open details" : "Open details",
-    "Photos and images" : "Photos and images",
-    "New folder creation cancelled" : "New folder creation cancelled",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
-    "All folders" : "All folders",
-    "Personal Files" : "Personal Files",
-    "Text file" : "Text file",
-    "New text file.txt" : "New text file.txt",
-    "%1$s (renamed)" : "%1$s (renamed)",
-    "renamed file" : "renamed file",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
-    "Filter file names …" : "Filter file names …",
     "Prevent warning dialogs from open or reenable them." : "Prevent warning dialogues from opening or reenable them.",
     "Show a warning dialog when changing a file extension." : "Show a warning dialog when changing a file extension.",
     "Speed up your Files experience with these quick shortcuts." : "Speed up your Files experience with these quick shortcuts.",
@@ -522,6 +428,24 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Navigate to the file on the left (in grid mode)",
     "Navigate to the file on the right (in grid mode)" : "Navigate to the file on the right (in grid mode)",
     "Toggle the grid view" : "Toggle the grid view",
-    "Open the sidebar for a file" : "Open the sidebar for a file"
+    "Open the sidebar for a file" : "Open the sidebar for a file",
+    "Save as …" : "Save as …",
+    "Converting files …" : "Converting files …",
+    "Converting file …" : "Converting file …",
+    "Deletion cancelled" : "Deletion cancelled",
+    "Edit locally" : "Edit locally",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Move cancelled" : "Move cancelled",
+    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
+    "Cancelled move or copy operation" : "Cancelled move or copy operation",
+    "Open details" : "Open details",
+    "Photos and images" : "Photos and images",
+    "New folder creation cancelled" : "New folder creation cancelled",
+    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
+    "All folders" : "All folders",
+    "Search everywhere …" : "Search everywhere …",
+    "Search here …" : "Search here …",
+    "Preparing …" : "Preparing …"
 },
 "nplurals=2; plural=(n != 1);");
