@@ -51,6 +51,10 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Sul puudvad õigused faili loomiseks antud asukohas",
     "The file could not be converted." : "Seda faili ei õnnestunud teisendada.",
     "Could not get relative path to converted file" : "Teisendatud faili suhtelist asukohta ei õnnestunud tuvastada",
+    "Limit must be a positive integer." : "Piirang peab olema positiivne täisarv",
+    "The replacement character may only be a single character." : "Asendatav tähemärk saab olla vaid üks tähemärk.",
+    "Filename sanitization already started." : "Failinime normaliseerimine on juba alanud.",
+    "No filename sanitization in progress." : "Failinimede normaliseerimine on hetkel töös.",
     "Favorite files" : "Lemmikfailid",
     "No favorites" : "Lemmikuid pole",
     "More favorites" : "Veel lemmikuid",
@@ -68,12 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "„{path}“ omandi üleandmine kasutajale {user} on tehtud.",
     "in %s" : "kaustas %s",
     "Transferred from %1$s on %2$s" : "Üleantud kasutajalt %1$s %2$s",
-    "Files compatibility" : "Failide ühilduvus",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Luba failinimede piiramine tagamaks, et sünkroniseerimine toimib kõikide platvormide klientide vahel. Vaikimisi on lubatud kõik POSIX-i standardile vastavad failinimed (seda järgivad Linux ja macOS).",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Kui võtad kasutusele Windowsiga ühilduvad failinimed, siis olemasolevaid mitteühilduvaid faile ei saa enam muuta, aga faili omanik saab failinime muuta ühilduvaks.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Lisaks on peale selle seadistuse kasutuselevõtmist võimalik kõik mitteühilduvad failid automaatselt ära muuta. Asjakohast teavet leiad kasutusjuhendist occ-käsku kirjeldavast peatükist.",
-    "Enforce Windows compatibility" : "Kasuta ühilduvust Windowsiga",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Sellega blokeerid niisuguste failinimede kasutamise, mis Windowsis ei toimiks. See tähendab mõnede nimede ja tähemärkide keelamist. Aga see seadistus ei jõusta suur- ja väiketähtede kasutust.",
     "File Management" : "Failihaldus",
     "Home" : "Kodu",
     "Target folder does not exist any more" : "Sihtkausta pole enam olemas",
@@ -106,6 +104,7 @@ OC.L10N.register(
     "Unknown date" : "Tundmatu kuupäev",
     "Clear filter" : "Tühjenda filter",
     "Modified" : "Muudetud",
+    "Search everywhere" : "Otsi kõikjalt",
     "Type" : "Tüüp",
     "Active filters" : "Aktiivsed filtrid",
     "Remove filter" : "Eemalda filter",
@@ -114,9 +113,9 @@ OC.L10N.register(
     "Name" : "Nimi",
     "File type" : "Failitüüp",
     "Size" : "Suurus",
-    "\"{displayName}\" failed on some elements" : "„{displayName}“ ei toiminud mõne objekti puhul",
-    "\"{displayName}\" batch action executed successfully" : "Pakktöötlus õnnestus: „{displayName}“",
-    "\"{displayName}\" action failed" : "Tegevus ei õnnestunud: „{displayName}“",
+    "{displayName}: failed on some elements" : "{displayName}: ei toiminud mõne objekti puhul",
+    "{displayName}: done" : "{displayName}: valmis",
+    "{displayName}: failed" : "{displayName}: ei õnnestunud",
     "Actions" : "Tegevused",
     "(selected)" : "(valitud)",
     "List of files and folders." : "Failide ja kaustade loend",
@@ -124,7 +123,11 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Võid kasutada nuppudega veerupäised järjestamiseks.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Jõudluse mõttes ei ole kogu loend esimesel hetkel tervikuna nähtav. Uued failid lisanduvad sedamööda, kuid sa loendis edasi liigud.",
     "File not found" : "Faili ei leitud",
-    "{count} selected" : "{count} valitud",
+    "_{count} selected_::_{count} selected_" : ["{count} valitud","{count} valitud"],
+    "Search everywhere …" : "Otsi kõikjalt…",
+    "Search here …" : "Otsi siin…",
+    "Search scope options" : "Otsinguulatuse valikud",
+    "Search here" : "Otsi siin",
     "{usedQuotaByte} used" : "{usedQuotaByte} kasutusel",
     "{used} of {quota} used" : "{used} / {quota} kasutusel",
     "{relative}% used" : "{relative}% kasutusel",
@@ -136,8 +139,27 @@ OC.L10N.register(
     "Create new folder" : "Loo uus kaust",
     "This name is already in use." : "See nimi on juba kasutusel.",
     "Create" : "Loo",
+    "Files starting with a dot are hidden by default" : "Punktiga algavad failinimed vaikimisi muudavad faili peidetuks",
+    "Failed to start filename sanitization." : "Failinime normaliseerimise alustamine ei õnnestunud.",
+    "Failed to refresh filename sanitization status." : "Failinime normaliseerimise oleku uuendamine ei õnnestunud.",
+    "Filename sanitization in progress." : "Failinime normaliseerimise on töös.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Hetkel töödeldud kasutajakontosid: {processedUsers}/{totalUsers}.",
+    "Preparing …" : "Ettevalmistamisel…",
+    "Refresh" : "Värskenda",
+    "All files have been santized for Windows filename support." : "Kõik failid on normaliseeritud vastavalt Windowsi failinimede toele.",
+    "Some files could not be sanitized, please check your logs." : "Mõnede failide normaliseerimine ei õnnestunud, palun vaata lisateavet logidest.",
+    "Sanitization errors" : "Normaliseerimise vead",
+    "Not sanitized filenames" : "Normaliseerimata failinimed",
+    "Windows filename support has been enabled." : "Windowsi failinimede tugi on kasutusel.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "See valik takistab kasutajatel uute mittetoetatud failinimede loomist. Olemasolevad failid pole ümber nimetatud ja see võib Windowsis tekitada veaolukordi.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Sa võid käivitada mittesobivate failinimede korrastamise. Seda tehakse taustateenuse poolt ning lõpetamiseks võib kuluda märgatavalt aega.",
+    "Please note that this may cause high workload on the sync clients." : "Palun arvesta, et see võib sünkroonimisklientides tekitada märgatava koormuse.",
+    "Limit" : "Piirang",
+    "This allows to configure how many users should be processed in one background job run." : "See võimaldab seadistada kasutajate arvu, kelle andmed ühe taustateenuse käivituskorraga töödeldakse.",
+    "Sanitize filenames" : "Normaliseeri failinimed",
+    "(starting)" : "(alustamisel)",
     "Fill template fields" : "Täida malli väljad",
-    "Submitting fields …" : "Saadan välju…",
+    "Submitting fields …" : "Saadan välju…",
     "Submit" : "Saada",
     "Choose a file or folder to transfer" : "Vali üleantav fail või kaust",
     "Transfer" : "Anna üle teisele kasutajale",
@@ -161,6 +183,51 @@ OC.L10N.register(
     "Do not show this dialog again." : "Ära näita seda vaadet enam uuesti.",
     "Select file or folder to link to" : "Vali lingitav fail või kaust",
     "Choose {file}" : "Vali „{file}“",
+    "Clipboard is not available" : "Lõikelaud ei ole saadaval",
+    "WebDAV URL copied" : "WebDAV-i võrguaadress on kopeeritud",
+    "Files settings" : "Failide seadistused",
+    "General" : "Üldine",
+    "Default view" : "Vaikimisi vaade",
+    "All files" : "Kõik failid",
+    "Personal files" : "Isiklikud failid",
+    "Sort favorites first" : "Järjesta lemmikud esimesena",
+    "Sort folders before files" : "Järjesta kaustad enne faile",
+    "Folder tree" : "Kaustapuu",
+    "Appearance" : "Välimus",
+    "Show hidden files" : "Näita peidetud faile",
+    "Show file type column" : "Näita failitüübi veergu",
+    "Show file extensions" : "Näita faililaiendeid",
+    "Crop image previews" : "Kadreeri piltide eelvaated",
+    "Additional settings" : "Lisaseadistused",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV-i võrguaadress",
+    "Copy" : "Kopeeri",
+    "How to access files using WebDAV" : "Ligipääs failidele WebDAV-i vahendusel",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Kaheastmeline autentimine on sellel kontol kasutusel ja seega pead välise WebDAV-i kliendi jaoks kasutama rakenduse salasõna.",
+    "Warnings" : "Hoiatused",
+    "Warn before changing a file extension" : "Hoiata enne faililaiendi muutmist",
+    "Warn before deleting files" : "Hoiata enne failide kustutamist",
+    "Keyboard shortcuts" : "Klaviatuuri kiirklahvid",
+    "File actions" : "Tegevused failidega",
+    "Rename" : "Muuda nime",
+    "Delete" : "Kustuta",
+    "Add or remove favorite" : "Lisa või eemalda lemmik",
+    "Manage tags" : "Halda silte",
+    "Selection" : "Valik",
+    "Select all files" : "Vali kõik failid",
+    "Deselect all" : "Eemalda kogu valik",
+    "Select or deselect" : "Vali või eemalda valik",
+    "Select a range" : "Vali vahemik",
+    "Navigation" : "Liikumine",
+    "Go to parent folder" : "Mine ülakausta",
+    "Go to file above" : "Mine ülal oleva faili juurde",
+    "Go to file below" : "Mine allpool oleva faili juurde",
+    "Go left in grid" : "Mine ruudustikus vasakule",
+    "Go right in grid" : "Mine ruudustikus paremale",
+    "View" : "Vaata",
+    "Toggle grid view" : "Lülita ruudustikuvaade sisse/välja",
+    "Open file sidebar" : "Ava failide külgriba",
+    "Show those shortcuts" : "Näita neid otseteid",
     "Share" : "Jaga",
     "Shared by link" : "Jagatud lingiga",
     "Shared" : "Jagatud",
@@ -173,74 +240,40 @@ OC.L10N.register(
     "Error during upload: {message}" : "Viga üleslaadimisel: {message}",
     "Error during upload, status code {status}" : "Viga üleslaadimisel, olekukood {status} ",
     "Unknown error during upload" : "Tundmatu viga üleslaadimisel",
-    "\"{displayName}\" action executed successfully" : "Toiming õnnestus: „{displayName}“",
     "Loading current folder" : "Laadin käesolevat kausta",
     "Retry" : "Proovi uuesti",
     "No files in here" : "Siin ei ole faile",
     "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
     "Go back" : "Mine tagasi",
-    "Filter file names …" : "Otsi failinimesid…",
     "Views" : "Vaated",
-    "Files settings" : "Failide seadistused",
-    "Your files" : "Sinu failid",
-    "Open in files" : "Ava failirakenduses",
-    "File cannot be accessed" : "Failile ligipääs puudub",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Faili kas ei leidu või sul puudub õigus selle vaatamiseks. Palu saatjat, et ta jagaks antud faili sulle.",
-    "Clipboard is not available" : "Lõikelaud ei ole saadaval",
-    "WebDAV URL copied to clipboard" : "WebDAV-i võrguaadress on kopeeritud lõikelauale",
-    "Sort favorites first" : "Järjesta lemmikud esimesena",
-    "Sort folders before files" : "Järjesta kaustad enne faile",
-    "Show hidden files" : "Näita peidetud faile",
-    "Show file type column" : "Näita failitüübi veergu",
-    "Crop image previews" : "Kadreeri piltide eelvaated",
-    "Enable the grid view" : "Võta kasutusele ruudustikuvaade",
-    "Enable folder tree" : "Võta kasutusele kaustapuu",
-    "Additional settings" : "Lisaseadistused",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV-i võrguaadress",
-    "Copy to clipboard" : "Kopeeri lõikelauale",
-    "Use this address to access your Files via WebDAV" : "Oma failidele WebDAV-i kaudu ligipääsemiseks kasuta seda aadressi",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Kui sa oled kaheastmelise autentimise kasutusele võtnud, siis pead looma ja kasutama rakenduse uut salasõna klikates siia.",
-    "Warnings" : "Hoiatused",
-    "Prevent warning dialogs from open or reenable them." : "Ära kasuta hoiatusteateid nende avamisel või uuesti kasutusele võtmisel.",
-    "Show a warning dialog when changing a file extension." : "Faililaiendi muutmisel näita hoiatust.",
-    "Keyboard shortcuts" : "Klaviatuuri kiirklahvid",
-    "Speed up your Files experience with these quick shortcuts." : "Tee failirakenduse kasutamine kiiremaks nende kiirklahvidega.",
-    "Open the actions menu for a file" : "Ava failitoimingute menüü",
-    "Rename a file" : "Muuda failinime",
-    "Delete a file" : "Kustuta fail",
-    "Favorite or remove a file from favorites" : "Märgi fail lemmikuks või eemalda olek lemmikuna",
-    "Manage tags for a file" : "Halda failide silte",
-    "Selection" : "Valik",
-    "Select all files" : "Vali kõik failid",
-    "Deselect all files" : "Eemalda kõikide failide valik",
-    "Select or deselect a file" : "Vali fail või eemalda valik",
-    "Select a range of files" : "Vali mitu faili",
-    "Navigation" : "Liikumine",
-    "Navigate to the parent folder" : "Mine ülakausta",
-    "Navigate to the file above" : "Liigu ülemise faili juurde",
-    "Navigate to the file below" : "Liigu alumise faili juurde",
-    "Navigate to the file on the left (in grid mode)" : "Liigu vasakpoolse faili juurde (ruudustikuvaates)",
-    "Navigate to the file on the right (in grid mode)" : "Liigu parempoolse faili juurde (ruudustikuvaates)",
-    "View" : "Vaata",
-    "Toggle the grid view" : "Lülita ruudustikuvaade sisse/välja",
-    "Open the sidebar for a file" : "Ava faili külgriba",
-    "Show those shortcuts" : "Näita neid otseteid",
     "You" : "Sina",
     "Shared multiple times with different people" : "Jagatud mitu korda eri kasutajate poolt",
+    "Unable to change the favorite state of the file" : "Faili olekut lemmikuna ei õnnestu muuta",
     "Error while loading the file data" : "Viga faili andmete laadimisel",
     "Owner" : "Omanik",
     "Remove from favorites" : "Eemalda lemmikutest",
     "Add to favorites" : "Lisa lemmikutesse",
     "Tags" : "Sildid",
+    "Your files" : "Sinu failid",
+    "Open in files" : "Ava failirakenduses",
+    "File cannot be accessed" : "Failile ligipääs puudub",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Faili kas ei leidu või sul puudub õigus selle vaatamiseks. Palu saatjat, et ta jagaks antud faili sulle.",
+    "No search results for “{query}”" : "„{query}“ otsingul pole tulemusi",
+    "Search for files" : "Otsi faile",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Luba failinimede piiramine tagamaks, et sünkroniseerimine toimib kõikide platvormide klientide vahel. Vaikimisi on lubatud kõik POSIX-i standardile vastavad failinimed (seda järgivad Linux ja macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Kui võtad kasutusele Windowsiga ühilduvad failinimed, siis olemasolevaid mitteühilduvaid faile ei saa enam muuta, aga faili omanik saab failinime muuta ühilduvaks.",
+    "Failed to toggle Windows filename support" : "Windowsi failinimede toe sisse/välja lülitamine ei õnnestunud",
+    "Files compatibility" : "Failide ühilduvus",
+    "Enforce Windows compatibility" : "Kasuta ühilduvust Windowsiga",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Sellega blokeerid niisuguste failinimede kasutamise, mis Windowsis ei toimiks. See tähendab mõnede nimede ja tähemärkide keelamist. Aga see seadistus ei jõusta suur- ja väiketähtede kasutust.",
     "Blank" : "Tühi",
     "Unable to create new file from template" : "Faili loomine mallist ebaõnnestus",
     "Pick a template for {name}" : "Vali mall „{name}“ faili jaoks",
     "Create a new file with the selected template" : "Loo valitud malli alusel uus fail",
     "Creating file" : "Fail on loomisel",
     "Save as {displayName}" : "Salvesta kui „{displayName}“",
-    "Save as …" : "Salvesta kui…",
-    "Converting files …" : "Teisendan faile…",
+    "Save as …" : "Salvesta kui…",
+    "Converting files …" : "Teisendan faile…",
     "Failed to convert files: {message}" : "Failide teisendamine ei õnnestunud: {message}",
     "All files failed to be converted" : "Kõiki faile ei õnnestunud teisendada",
     "One file could not be converted: {message}" : "Ühe faili teisendamine ei õnnestunud: {message}",
@@ -248,11 +281,10 @@ OC.L10N.register(
     "_One file successfully converted_::_%n files successfully converted_" : ["Ühe faili teisendamine õnnestus","%n faili teisendamine õnnestus"],
     "Files successfully converted" : "Failide teisendamine õnnestus",
     "Failed to convert files" : "Failide teisendamine ei õnnestunud",
-    "Converting file …" : "Teisendan faili…",
+    "Converting file …" : "Teisendan faile…",
     "File successfully converted" : "Faili teisendamine õnnestus",
     "Failed to convert file: {message}" : "Faili teisendamine ei õnnestunud: {message}",
     "Failed to convert file" : "Faili teisendamine ei õnnestunud",
-    "Deletion cancelled" : "Kustutamine on tühistatud",
     "Leave this share" : "Lahku jaoskaustast",
     "Leave these shares" : "Lahku neist jaoskaustadest",
     "Disconnect storage" : "Ühenda andmeruum lahti",
@@ -263,29 +295,29 @@ OC.L10N.register(
     "Delete files" : "Kustuta failid",
     "Delete folder" : "Kustuta kaust",
     "Delete folders" : "Kustuta kaustad",
-    "Delete" : "Kustuta",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sa oled jäädavalt kustutamas {count} objekti","Sa oled jäädavalt kustutamas {count} objekti"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sa oled kustutamas {count} objekti","Sa oled kustutamas {count} objekti"],
     "Confirm deletion" : "Kinnita kustutamine",
     "Cancel" : "Loobu",
-    "Moving \"{source}\" to \"{destination}\" …" : "Teisaldan „{source}“ → „{destination}“…",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopeerin „{source}“ → „{destination}“…",
+    "Download" : "Laadi alla",
+    "The requested file is not available." : "Soovitud fail pole saadaval.",
+    "The requested files are not available." : "Soovitud failid pole saadaval.",
+    "Moving \"{source}\" to \"{destination}\" …" : "Teisaldan „{source}“ → „{destination}“…",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopeerin „{source}“ → „{destination}“…",
+    "Destination is not a folder" : "Sihtasukoht pole kaust",
+    "This file/folder is already in that directory" : "See fail või kaust juba asub selles kaustas",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Sa ei saa faili või kausta iseendaks teisaldada ega teisaldada kausta iseenda alamkausta",
     "(copy)" : "(koopia)",
     "(copy %n)" : "(%n koopia)",
-    "Move cancelled" : "Teisaldamine on katkestatud",
     "A file or folder with that name already exists in this folder" : "Selles kaustas juba on olemas sama nimega fail või kaust",
     "The files are locked" : "Need failid on lukustatud",
     "The file does not exist anymore" : "Neid faile pole enam olemas",
     "Choose destination" : "Vali sihtkaust",
     "Copy to {target}" : "Kopeeri kausta {target}",
-    "Copy" : "Kopeeri",
     "Move to {target}" : "Teisalda kausta {target}",
     "Move" : "Teisalda",
     "Move or copy operation failed" : "Teisaldamine või kopeerimine ei õnnestunud",
     "Move or copy" : "Liiguta või kopeeri",
-    "Cancelled move or copy of \"{filename}\"." : "„{filename}“ faili teisaldamine või kopeerimine on katkestatud.",
-    "Cancelled move or copy operation" : "Teisaldamine või kopeerimine on katkestatud",
     "Open folder {displayName}" : "Ava kaust {displayName}",
     "Open in Files" : "Ava failirakenduses",
     "Open locally" : "Ava kohalikust andmeruumist",
@@ -294,8 +326,7 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fail peaks nüüd sinu seadmes või arvutis olema avatud. Kui see nii pole, siis palun kontrolli, et töölauarakendus on paigaldatud.",
     "Retry and close" : "Proovi uuesti ja sulge",
     "Open online" : "Ava võrgust",
-    "Rename" : "Muuda nime",
-    "Open details" : "Ava üksikasjad",
+    "Details" : "Üksikasjad",
     "View in folder" : "Vaata kaustas",
     "Today" : "Täna",
     "Last 7 days" : "Viimase 7 päeva jooksul",
@@ -308,15 +339,15 @@ OC.L10N.register(
     "PDFs" : "PDF-failid",
     "Folders" : "Kaustad",
     "Audio" : "Helifailid",
-    "Photos and images" : "Fotod ja pildid",
+    "Images" : "Pildid",
     "Videos" : "Videod",
-    "New folder creation cancelled" : "Uue kausta loomine on katkestatud",
     "Created new folder \"{name}\"" : "Uus „{name}“ kaust on loodud",
     "Unable to initialize the templates directory" : "Mallide kausta loomine ebaõnnestus",
     "Create templates folder" : "Loo mallide kaust",
     "Templates" : "Mallid",
     "New template folder" : "Uus kaustamall",
     "In folder" : "Kaustas",
+    "Search in all files" : "Otsi kõikide failide seast",
     "Search in folder: {folder}" : "Otsi kaustast: {folder}",
     "One of the dropped files could not be processed" : "Ühte siia lisatud failidest ei õnnestunud töödelda",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Sinu veebibrauser ei toeta „Filesystem API“ liidestust. Kaustad jäävad üleslaadimata",
@@ -331,8 +362,11 @@ OC.L10N.register(
     "Files moved successfully" : "Failide teisaldamine õnnestus",
     "Conflicts resolution skipped" : "Andmekonfilkti lahendamine jäi vahele",
     "Upload cancelled" : "Üleslaadimine on katkestatud",
+    "Could not rename \"{oldName}\", it does not exist any more" : "„{oldName}“ faili nime muutmine ei õnnestunud, seda pole enam olemas",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "„{newName}“ nimi on juba „{dir}“ kaustas kasutusel. Palun vali teine nimi.",
+    "Could not rename \"{oldName}\"" : "„{oldName}“ faili nime muutmine ei õnnestunud",
     "This operation is forbidden" : "See toiming on keelatud",
-    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval, palun kontrolli logifaile või võta ühendust administraatoriga",
+    "This folder is unavailable, please try again later or contact the administration" : "See kaust pole saadaval, palun proovi hiljem uuesti või võta ühendust haldajaaga",
     "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
     "Unexpected error: {error}" : "Tundmatu viga: {error}",
     "_%n file_::_%n files_" : ["%n fail","%n faili"],
@@ -346,10 +380,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Sinu lemmikfailide ja -kaustade loend.",
     "No favorites yet" : "Lemmikuid veel pole",
     "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
-    "All files" : "Kõik failid",
     "List of your files and folders." : "Sinu failide ja kaustade loend.",
-    "All folders" : "Kõik kaustad",
-    "Personal files" : "Isiklikud failid",
     "List of your files and folders that are not shared." : "Sinu mittejagatud failide ja kaustade loend",
     "No personal files found" : "Isiklikke faile ei leitud",
     "Files that are not shared will show up here." : "Siin kuvatakse faile ja kaustu, mida sa pole teistega jaganud.",
@@ -357,106 +388,64 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Hiljuti muudetud failide ja kaustade loend.",
     "No recently modified files" : "Hiljuti muudetud faile pole.",
     "Files and folders you recently modified will show up here." : "Failid ja kaustad, mida oled hiljuti muutnud, ilmuvad siia.",
+    "Search" : "Otsi",
+    "Search results within your files." : "Otsingutulemusd sinu failide seast.",
     "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
     "Select all" : "Vali kõik",
     "Upload too large" : "Üleslaadimine on liiga suur",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületavad serveri poolt üleslaaditavatele failidele määratud maksimaalse suuruse.",
-    "File could not be found" : "Faili ei leitud",
-    "Download" : "Laadi alla",
-    "Show list view" : "Näita loendivaadet",
-    "Show grid view" : "Näita ruudustikuvaadet",
-    "Close" : "Sulge",
-    "Could not create folder \"{dir}\"" : "Kausta \"{dir}\" loomine ebaõnnestus",
-    "This will stop your current uploads." : "See peatab praegused üleslaadimised.",
-    "Upload cancelled." : "Üleslaadimine tühistati.",
-    "Processing files …" : "Failide töötlemine …",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida „{filename}“, kuna see on kaust või selle suurus on 0 baiti",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
-    "Target folder \"{dir}\" does not exist any more" : "Kausta \"{dir}\" pole enam olemas",
-    "An unknown error has occurred" : "Tekkis tundmatu tõrge",
-    "File could not be uploaded" : "Faili üleslaadimine ebaõnnestus",
-    "Uploading …" : "Üleslaadmisel...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Üleslaadimisel… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Selle objekti üleslaadimine ei ole toetatud",
-    "Error when assembling chunks, status code {status}" : "Tükkide kokkupanemise viga, staatuskood {status}",
-    "Choose target folder" : "Vali sihtkaust",
-    "Set reminder" : "Lisa meeldetuletus",
-    "Edit locally" : "Muuda lokaalselt",
-    "Open" : "Ava",
-    "Could not load info for file \"{file}\"" : "Faili \"{file}\" info laadimine ebaõnnestus",
-    "Details" : "Üksikasjad",
-    "Please select tag(s) to add to the selection" : "Palun vali sildid, mida valitutele lisada",
-    "Apply tag(s) to selection" : "Rakenda sildid valitutele",
-    "Select directory \"{dirName}\"" : "Vali kaust „{dirName}“",
-    "Select file \"{fileName}\"" : "Vali fail „{fileName}“",
-    "Unable to determine date" : "Kuupäeva tuvastamine ebaõnnestus",
-    "Could not move \"{file}\", target exists" : "\"{file}\" liigutamine ebaõnnestus, sihtfail on juba olemas",
-    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
-    "copy" : "koopia",
-    "Could not copy \"{file}\", target exists" : "\"{file}\" kopeerimine ebaõnnestus, sihtfail on juba olemas",
-    "Could not copy \"{file}\"" : "\"{file}\" kopeerimine ebaõnnestus",
-    "Copied {origin} inside {destination}" : "{origin} kopeeritud kausta {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ja {nbfiles} teist faili kopeeritud kausta {destination}",
-    "{newName} already exists" : "{newName} on juba olemas",
-    "Could not rename \"{fileName}\", it does not exist any more" : "„{fileName}“ faili nime muutmine ei õnnestunud, seda pole enam olemas",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on juba \"{dir}\" kaustas kasutusel. Palun vali teine nimi.",
-    "Could not rename \"{fileName}\"" : "„{fileName}“ faili nime muutmine ei õnnestunud",
-    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
-    "Could not create file \"{file}\" because it already exists" : "Faili \"{file}\" loomine ebaõnnestus, sest see on juba olemas",
-    "Could not create folder \"{dir}\" because it already exists" : "Kausta \"{dir}\" loomine ebaõnnestus, sest see on juba olemas",
-    "Could not fetch file details \"{file}\"" : "Ei õnnestunud laadida „{file}“ faili üksikasju",
-    "Error deleting file \"{fileName}\"." : "Viga „{fileName}“ faili kustutamisel.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Teistest kaustadest ei leitud {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Teistest kaustadest otsimiseks sisesta rohkem kui kaks sümbolit",
-    "{dirs} and {files}" : "{dirs} ja {files}",
-    "_including %n hidden_::_including %n hidden_" : ["sealhulgas %n peidetud","sealhulgas %n peidetud"],
-    "You do not have permission to upload or create files here" : "Sul pole luba siia faile lisada ja üles laadida",
-    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
-    "New" : "Uus",
-    "New file/folder menu" : "Uue faili või kausta menüü",
-    "Select file range" : "Vali failivahemik",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} kasutusel",
-    "\"{name}\" is an invalid file name." : "„{name}“ on vigane failinimi.",
-    "File name cannot be empty." : "Failinimi ei saa olla tühi.",
-    "\"/\" is not allowed inside a file name." : "„/“ pole failinimedes lubatud.",
-    "\"{name}\" is not an allowed filetype" : "„{name}“ pole lubatud failitüüp",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} andmeruum on täis - faile ei saa enam uuendada ega sünkroniseerida!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "„{mountPoint}“ grupikausta andmeruum on täis - faile ei saa enam uuendada ega sünkroniseerida!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Väline andmeruum  „{mountPoint}“ on täis - faile ei saa enam uuendada ega sünkroniseerida!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Sinu andmeruum on täis - faile ei saa enam uuendada ega sünkroniseerida!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Kasutaja {owner} andmeruum on peaaegu täis ({usedSpacePercent}%)",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "„{mountPoint}“ grupi andmeruum on peaaegu täis ({usedSpacePercent}%)",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Väline andmeruum „{mountPoint}“ on peaaegu täis ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Su andmeruum on peaaegu täis ({usedSpacePercent}%)",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["vastab tingimusele „{filter}“","vastab tingimustele „{filter}“"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Otselink on kopeeritud (toimib ainult nende kasutajate puhul, kellel on ligipääs sellele failile/kaustale)",
-    "Path" : "Asukoht",
-    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
-    "Favored" : "Märgitud lemmikuks",
-    "Favor" : "Märgi lemmikuks",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopeeri otselink (töötab ainult nende kasutajate puhul, kellel on ligipääs sellele failile/kaustale)",
-    "Upload file" : "Laadi fail üles",
-    "Not favored" : "Pole märgitud lemmikuks",
-    "An error occurred while trying to update the tags" : "Siltide uuendamisel tekkis tõrge",
-    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
-    "Submitting fields…" : "Saadan välju…",
-    "Filter filenames…" : "Otsi failinimesid…",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} kaust","{folderCount} kausta"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fail","{fileCount} faili"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fail ja {folderCount} kaust","1 fail ja {folderCount} kausta"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fail ja 1 kaust","{fileCount} faili ja 1 kaust"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} faili ja {folderCount} kausta",
-    "Personal Files" : "Isiklikud Failid",
-    "Text file" : "Tekstifail",
-    "New text file.txt" : "Uus tekstifail.txt",
     "%1$s (renamed)" : "%1$s (nimi on muudetud)",
     "renamed file" : "muudetud nimega fail",
+    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Kui võtad kasutusele Windowsiga ühilduvad failinimed, siis olemasolevad mitteühilduvaid faile ei saa enam muuta, aga faili omanik saab failinime muuta ühilduvaks.",
-    "{count} files could not be converted" : "{count} faili ei õnnestunud teisendada",
-    "{count} files successfully converted" : "{count} faili teisendamine õnnestus"
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Lisaks on peale selle seadistuse kasutuselevõtmist võimalik kõik mitteühilduvad failid automaatselt ära muuta. Asjakohast teavet leiad kasutusjuhendist occ-käsku kirjeldavast peatükist.",
+    "\"{displayName}\" failed on some elements" : "„{displayName}“ ei toiminud mõne objekti puhul",
+    "\"{displayName}\" batch action executed successfully" : "Pakktöötlus õnnestus: „{displayName}“",
+    "\"{displayName}\" action failed" : "Tegevus ei õnnestunud: „{displayName}“",
+    "Submitting fields …" : "Saadan välju…",
+    "\"{displayName}\" action executed successfully" : "Toiming õnnestus: „{displayName}“",
+    "Filter file names …" : "Otsi failinimesid…",
+    "WebDAV URL copied to clipboard" : "WebDAV-i võrguaadress on kopeeritud lõikelauale",
+    "Enable the grid view" : "Võta kasutusele ruudustikuvaade",
+    "Enable folder tree" : "Võta kasutusele kaustapuu",
+    "Copy to clipboard" : "Kopeeri lõikelauale",
+    "Use this address to access your Files via WebDAV" : "Oma failidele WebDAV-i kaudu ligipääsemiseks kasuta seda aadressi",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Kui sa oled kaheastmelise autentimise kasutusele võtnud, siis pead looma ja kasutama rakenduse uut salasõna klikates siia.",
+    "Prevent warning dialogs from open or reenable them." : "Ära kasuta hoiatusteateid nende avamisel või uuesti kasutusele võtmisel.",
+    "Show a warning dialog when changing a file extension." : "Faililaiendi muutmisel näita hoiatust.",
+    "Speed up your Files experience with these quick shortcuts." : "Tee failirakenduse kasutamine kiiremaks nende kiirklahvidega.",
+    "Open the actions menu for a file" : "Ava failitoimingute menüü",
+    "Rename a file" : "Muuda failinime",
+    "Delete a file" : "Kustuta fail",
+    "Favorite or remove a file from favorites" : "Märgi fail lemmikuks või eemalda olek lemmikuna",
+    "Manage tags for a file" : "Halda failide silte",
+    "Deselect all files" : "Eemalda kõikide failide valik",
+    "Select or deselect a file" : "Vali fail või eemalda valik",
+    "Select a range of files" : "Vali mitu faili",
+    "Navigate to the parent folder" : "Mine ülakausta",
+    "Navigate to the file above" : "Liigu ülemise faili juurde",
+    "Navigate to the file below" : "Liigu alumise faili juurde",
+    "Navigate to the file on the left (in grid mode)" : "Liigu vasakpoolse faili juurde (ruudustikuvaates)",
+    "Navigate to the file on the right (in grid mode)" : "Liigu parempoolse faili juurde (ruudustikuvaates)",
+    "Toggle the grid view" : "Lülita ruudustikuvaade sisse/välja",
+    "Open the sidebar for a file" : "Ava faili külgriba",
+    "Save as …" : "Salvesta kui…",
+    "Converting files …" : "Teisendan faile…",
+    "Converting file …" : "Teisendan faili…",
+    "Deletion cancelled" : "Kustutamine on tühistatud",
+    "Edit locally" : "Muuda lokaalselt",
+    "Moving \"{source}\" to \"{destination}\" …" : "Teisaldan „{source}“ → „{destination}“…",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopeerin „{source}“ → „{destination}“…",
+    "Move cancelled" : "Teisaldamine on katkestatud",
+    "Cancelled move or copy of \"{filename}\"." : "„{filename}“ faili teisaldamine või kopeerimine on katkestatud.",
+    "Cancelled move or copy operation" : "Teisaldamine või kopeerimine on katkestatud",
+    "Open details" : "Ava üksikasjad",
+    "Photos and images" : "Fotod ja pildid",
+    "New folder creation cancelled" : "Uue kausta loomine on katkestatud",
+    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval, palun kontrolli logifaile või võta ühendust administraatoriga",
+    "All folders" : "Kõik kaustad",
+    "Search everywhere …" : "Otsi kõikjalt…",
+    "Search here …" : "Otsi siin…",
+    "Preparing …" : "Ettevalmistamisel…"
 },
 "nplurals=2; plural=(n != 1);");
