@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
  * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
@@ -134,9 +135,8 @@ class SharedStorage extends Jail implements LegacyISharedStorage, ISharedStorage
 				// this is probably because some code path has caused recursion during the share setup
 				// we setup a "failed storage" so `getWrapperStorage` doesn't return null.
 				// If the share setup completes after this the "failed storage" will be overwritten by the correct one
-				$ex = new \Exception('Possible share setup recursion detected for share ' . $this->superShare->getId());
-				$this->logger->warning($ex->getMessage(), ['exception' => $ex, 'app' => 'files_sharing']);
-				$this->storage = new FailedStorage(['exception' => $ex]);
+				$this->logger->warning('Possible share setup recursion detected');
+				$this->storage = new FailedStorage(['exception' => new \Exception('Possible share setup recursion detected')]);
 				$this->cache = new FailedCache();
 				$this->rootPath = '';
 			}
@@ -464,7 +464,7 @@ class SharedStorage extends Jail implements LegacyISharedStorage, ISharedStorage
 	 */
 	public function unshareStorage(): bool {
 		foreach ($this->groupedShares as $share) {
-			\OC::$server->getShareManager()->deleteFromSelf($share, $this->user);
+			Server::get(\OCP\Share\IManager::class)->deleteFromSelf($share, $this->user);
 		}
 		return true;
 	}
