@@ -4,7 +4,6 @@ OC.L10N.register(
     "Hello %s" : "Përshëndetje %s",
     "Hello %s," : "Përshëndetje %s,",
     "Notifications" : "Njoftimet",
-    "seconds ago" : "sekonda më parë",
     "Dismiss" : "Hiq",
     "in {path}" : "në {path}",
     "No notifications" : "Asnjë njoftim",
@@ -14,6 +13,7 @@ OC.L10N.register(
     "1 day" : "1 ditë ",
     "Your settings have been updated." : "Rregullimet tuaja u përditësuan",
     "None" : "Asnjë",
-    "You need to set up your email address before you can receive notification emails." : "Kërkohet të caktoni adresën tuaj email, përpara se të mund të merrni email-e njoftimesh."
+    "You need to set up your email address before you can receive notification emails." : "Kërkohet të caktoni adresën tuaj email, përpara se të mund të merrni email-e njoftimesh.",
+    "seconds ago" : "sekonda më parë"
 },
 "nplurals=2; plural=(n != 1);");
