@@ -14,22 +14,26 @@ OC.L10N.register(
     "File not found" : "Berkas tidak ditemukan",
     "Text" : "Teks",
     "Translate" : "Terjemahkan",
+    "Delete task" : "Hapus tugas",
     "Reload" : "Muat ulang",
-    "Edit guest name" : "Edit nama tamu",
     "Guest" : "Tamu",
-    "Save guest name" : "Simpan nama tamu",
+    "you" : "Anda",
+    "edit" : "ubah",
+    "Copy link" : "Salin tautan",
     "guest" : "pengunjung",
     "Saving …" : "Menyimpan ...",
     "Saved" : "Disimpan",
+    "Unsaved changes" : "Perubahan belum disimpan",
     "Keyboard shortcuts" : "Pintasan keyboard",
     "Link" : "Tautan",
     "Undo" : "Undo",
+    "Redo" : "Ulang lagi",
     "Cancel" : "Batal",
     "URL" : "URL",
     "Formatting help" : "Bantuan pemformatan",
-    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
     "to" : "untuk",
     "Replace" : "Timpa",
+    "Upload" : "Unggah",
     "Edit" : "Sunting",
     "Source code" : "Kode sumber",
     "Both" : "Keduanya",
@@ -37,10 +41,10 @@ OC.L10N.register(
     "Lists" : "Daftar",
     "Details" : "Detail",
     "Formatting" : "Pemformatan",
-    "Info" : "Info",
-    "Success" : "Berhasil",
-    "Warning" : "Peringatan",
-    "Control" : "Kendali",
-    "Add notes, lists or links …" : "Tambahkan catatan, daftar, atau tautan..."
+    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
+    "Choose" : "Pilih",
+    "Add folder description" : "Tambahkan deskripsi folder",
+    "Edit guest name" : "Edit nama tamu",
+    "Save guest name" : "Simpan nama tamu"
 },
 "nplurals=1; plural=0;");
