@@ -4,6 +4,8 @@ OC.L10N.register(
     "File not found" : "Файл олдсонгүй",
     "Translate" : "Орчуулга",
     "Guest" : "Зочин",
+    "you" : "та",
+    "edit" : "Засварлах",
     "Saved" : "Хадгалах",
     "Link" : "Холбоос",
     "Undo" : "буцах",
@@ -15,8 +17,6 @@ OC.L10N.register(
     "Edit" : "засварлах",
     "Source code" : "эх үүсвэр талын код",
     "Details" : "Дэлгэрэнгүй",
-    "Choose" : "Сонгох",
-    "Info" : "Info",
-    "Warning" : "Warning"
+    "Choose" : "Сонгох"
 },
 "nplurals=2; plural=(n != 1);");
