@@ -36,9 +36,10 @@ class NodeCopiedListener implements IEventListener {
 			&& $target instanceof File
 			&& $target->getMimeType() === 'text/markdown'
 		) {
-			$this->attachmentService->copyAttachments($source, $target);
+			$fileIdMapping = $this->attachmentService->copyAttachments($source, $target);
 			$target->unlock(ILockingProvider::LOCK_SHARED);
 			AttachmentService::replaceAttachmentFolderId($source, $target);
+			AttachmentService::replaceAttachmentFileIds($target, $fileIdMapping);
 			$target->lock(ILockingProvider::LOCK_SHARED);
 		}
 	}
