@@ -7,13 +7,23 @@ OC.L10N.register(
     "Error" : "Помилка",
     "Weather status" : "Прогноз погоди",
     "Weather status in your dashboard" : "Статус погоди на вашій інформаційній панелі",
-    "Detect location" : "Визначити місце розташування",
-    "Set custom address" : "Встановити власну адресу",
-    "Favorites" : "Із зірочкою",
+    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Стан погоди інтегрований в додаток Dashboard.\n    Географічне розташування може бути визначено автоматично або вручну. Потім відображається прогноз на 6 годин.\n    Цей статус також може бути інтегрований в інші місця, наприклад, в додаток \"Календар\".",
     "{temperature} {unit} clear sky later today" : "{temperature} {unit} ясне небо пізніше сьогодні",
     "{temperature} {unit} clear sky" : "{temperature} {unit} ясне небо",
     "{temperature} {unit} cloudy later today" : "{temperature} {unit} хмарно пізніше сьогодні",
     "{temperature} {unit} cloudy" : "{temperature} {unit} хмарно",
+    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} сніг та грім сьогодні ввечері",
+    "{temperature} {unit} snow and thunder" : "{temperature} {unit} сніг і грім",
+    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} сьогодні ввечері снігопад та грім",
+    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} снігові зливи та грім",
+    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} сьогодні ввечері снігопади, грім та полярні сутінки",
+    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} снігові зливи, грім і полярні сутінки",
+    "{temperature} {unit} snow showers later today" : "{temperature} {unit} Сьогодні ввечері сніг зі снігом.",
+    "{temperature} {unit} snow showers" : "{temperature} {unit} снігопади",
+    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} Сьогодні ввечері снігопади та полярні сутінки",
+    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} снігопади та полярні сутінки",
+    "{temperature} {unit} snow later today" : "{temperature} {unit} Сьогодні сніг.",
+    "{temperature} {unit} snow" : "{temperature} {unit} сніг",
     "{temperature} {unit} fair weather later today" : "{temperature} {unit} гарна погода пізніше сьогодні",
     "{temperature} {unit} fair weather" : "{temperature} {unit} гарна погода",
     "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} мінлива хмарність пізніше сьогодні",
@@ -34,6 +44,7 @@ OC.L10N.register(
     "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} проливні дощі",
     "More weather for {adr}" : "Більше інформації про погоду для {adr}",
     "Loading weather" : "Завантаження інформації про стан погоди",
+    "Set location for weather" : "Встановіть місце для погоди",
     "Remove from favorites" : "Прибрати зірочку",
     "Add as favorite" : "Позначити зірочкою",
     "You are not logged in." : "Ви не ввійшли до системи.",
@@ -44,7 +55,9 @@ OC.L10N.register(
     "There was an error setting the location." : "Під час встановлення місця розташування сталася помилка.",
     "There was an error saving the mode." : "Під час збереження режиму сталася помилка.",
     "There was an error using personal address." : "Під час використання особистої адреси сталася помилка.",
-    "Set location for weather" : "Встановіть місце для погоди",
-    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Статус погоди інтегрований до застосунку з панеллю віджетів (Dashboard). Розташування користувача може визначатися автоматично або вручну. В застосунку показується прогноз на 6 годин.\nСтатус може показуватися й інших застосунках, як-от у \"Календарі\"."
+    "Unknown weather code" : "Невідомий код погоди",
+    "Detect location" : "Визначити місце розташування",
+    "Set custom address" : "Встановити власну адресу",
+    "Favorites" : "Із зірочкою"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
