@@ -8,8 +8,10 @@ declare(strict_types=1);
  */
 namespace OC\Avatar;
 
+use OCP\Color;
 use OCP\Files\SimpleFS\InMemoryFile;
 use OCP\Files\SimpleFS\ISimpleFile;
+use OCP\IConfig;
 use Psr\Log\LoggerInterface;
 
 /**
@@ -23,9 +25,10 @@ class GuestAvatar extends Avatar {
 	 */
 	public function __construct(
 		private string $userDisplayName,
+		IConfig $config,
 		LoggerInterface $logger,
 	) {
-		parent::__construct($logger);
+		parent::__construct($config, $logger);
 	}
 
 	/**
@@ -86,4 +89,13 @@ class GuestAvatar extends Avatar {
 	public function isCustomAvatar(): bool {
 		return false;
 	}
+
+
+	/**
+	 * Different color than for authorized user with the same name
+	 * to make it harder to impersonate people.
+	 */
+	public function avatarBackgroundColor(string $hash): Color {
+		return parent::avatarBackgroundColor($hash . ' (guest)');
+	}
 }
